pub fn negotiate_protocol(
client: &ProtocolOffer,
server: &ProtocolOffer,
) -> Result<ProtocolVersion, ProtocolNegotiationError>Expand description
Selects the lexicographically newest version present in both offers.
pub fn negotiate_protocol(
client: &ProtocolOffer,
server: &ProtocolOffer,
) -> Result<ProtocolVersion, ProtocolNegotiationError>Selects the lexicographically newest version present in both offers.