pub struct ActionCall {
pub id: Uuid,
pub name: String,
pub arguments: Value,
}Fields
id: Uuidname: Stringarguments: ValueTrait Implementations
Sourceimpl Clone for ActionCall
impl Clone for ActionCall
Sourcefn clone(&self) -> ActionCall
fn clone(&self) -> ActionCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActionCall
impl Debug for ActionCall
Sourceimpl<'de> Deserialize<'de> for ActionCall
impl<'de> Deserialize<'de> for ActionCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ActionCall
impl JsonSchema for ActionCall
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ActionCall
impl PartialEq for ActionCall
Sourceimpl Serialize for ActionCall
impl Serialize for ActionCall
impl StructuralPartialEq for ActionCall