pub struct ActionDefinition {
pub name: String,
pub description: String,
pub input_schema: Value,
pub protection: ActionProtection,
}Fields
name: Stringdescription: Stringinput_schema: Valueprotection: ActionProtectionTrait Implementations
Sourceimpl Clone for ActionDefinition
impl Clone for ActionDefinition
Sourcefn clone(&self) -> ActionDefinition
fn clone(&self) -> ActionDefinition
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ActionDefinition
impl Debug for ActionDefinition
Sourceimpl<'de> Deserialize<'de> for ActionDefinition
impl<'de> Deserialize<'de> for ActionDefinition
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ActionDefinition
impl JsonSchema for ActionDefinition
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ActionDefinition
impl PartialEq for ActionDefinition
Sourceimpl Serialize for ActionDefinition
impl Serialize for ActionDefinition
impl StructuralPartialEq for ActionDefinition