pub struct AssetRef {
pub id: String,
pub media_type: String,
pub uri: String,
pub sha256: Option<String>,
}Fields
id: Stringmedia_type: Stringuri: Stringsha256: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for AssetRef
impl<'de> Deserialize<'de> for AssetRef
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AssetRef
Sourceimpl JsonSchema for AssetRef
impl JsonSchema for AssetRef
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for AssetRef