pub struct DeviceDisconnectResult {
pub disconnected: bool,
}Expand description
Result returned by device.disconnect.
Fields
disconnected: boolTrait Implementations
Sourceimpl Clone for DeviceDisconnectResult
impl Clone for DeviceDisconnectResult
Sourcefn clone(&self) -> DeviceDisconnectResult
fn clone(&self) -> DeviceDisconnectResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for DeviceDisconnectResult
Sourceimpl Debug for DeviceDisconnectResult
impl Debug for DeviceDisconnectResult
Sourceimpl<'de> Deserialize<'de> for DeviceDisconnectResult
impl<'de> Deserialize<'de> for DeviceDisconnectResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeviceDisconnectResult
Sourceimpl JsonSchema for DeviceDisconnectResult
impl JsonSchema for DeviceDisconnectResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DeviceDisconnectResult
impl PartialEq for DeviceDisconnectResult
Sourceimpl Serialize for DeviceDisconnectResult
impl Serialize for DeviceDisconnectResult
impl StructuralPartialEq for DeviceDisconnectResult