pub struct DeviceInfo {
pub id: DeviceId,
pub name: String,
pub platform: Platform,
pub os_version: Option<String>,
pub connected: bool,
}Fields
id: DeviceIdname: Stringplatform: Platformos_version: Option<String>connected: boolTrait Implementations
Sourceimpl Clone for DeviceInfo
impl Clone for DeviceInfo
Sourcefn clone(&self) -> DeviceInfo
fn clone(&self) -> DeviceInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceInfo
impl Debug for DeviceInfo
Sourceimpl<'de> Deserialize<'de> for DeviceInfo
impl<'de> Deserialize<'de> for DeviceInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeviceInfo
Sourceimpl JsonSchema for DeviceInfo
impl JsonSchema for DeviceInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DeviceInfo
impl PartialEq for DeviceInfo
Sourceimpl Serialize for DeviceInfo
impl Serialize for DeviceInfo
impl StructuralPartialEq for DeviceInfo