pub struct DeviceSelectParams {
pub device_id: DeviceId,
}Expand description
Parameters accepted by device.select.
Fields
device_id: DeviceIdTrait Implementations
Sourceimpl Clone for DeviceSelectParams
impl Clone for DeviceSelectParams
Sourcefn clone(&self) -> DeviceSelectParams
fn clone(&self) -> DeviceSelectParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceSelectParams
impl Debug for DeviceSelectParams
Sourceimpl<'de> Deserialize<'de> for DeviceSelectParams
impl<'de> Deserialize<'de> for DeviceSelectParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeviceSelectParams
Sourceimpl JsonSchema for DeviceSelectParams
impl JsonSchema for DeviceSelectParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DeviceSelectParams
impl PartialEq for DeviceSelectParams
Sourceimpl Serialize for DeviceSelectParams
impl Serialize for DeviceSelectParams
impl StructuralPartialEq for DeviceSelectParams