pub struct DeviceSelectResult {
pub device: DeviceInfo,
}Expand description
Result returned by device.select.
Fields
device: DeviceInfoTrait Implementations
Sourceimpl Clone for DeviceSelectResult
impl Clone for DeviceSelectResult
Sourcefn clone(&self) -> DeviceSelectResult
fn clone(&self) -> DeviceSelectResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DeviceSelectResult
impl Debug for DeviceSelectResult
Sourceimpl<'de> Deserialize<'de> for DeviceSelectResult
impl<'de> Deserialize<'de> for DeviceSelectResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DeviceSelectResult
Sourceimpl JsonSchema for DeviceSelectResult
impl JsonSchema for DeviceSelectResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DeviceSelectResult
impl PartialEq for DeviceSelectResult
Sourceimpl Serialize for DeviceSelectResult
impl Serialize for DeviceSelectResult
impl StructuralPartialEq for DeviceSelectResult