pub struct DevicesListResult {
pub devices: Vec<DeviceInfo>,
pub selected_device_id: Option<DeviceId>,
}Expand description
Result returned by devices.list.
Fields
devices: Vec<DeviceInfo>selected_device_id: Option<DeviceId>Trait Implementations
Sourceimpl Clone for DevicesListResult
impl Clone for DevicesListResult
Sourcefn clone(&self) -> DevicesListResult
fn clone(&self) -> DevicesListResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DevicesListResult
impl Debug for DevicesListResult
Sourceimpl<'de> Deserialize<'de> for DevicesListResult
impl<'de> Deserialize<'de> for DevicesListResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for DevicesListResult
Sourceimpl JsonSchema for DevicesListResult
impl JsonSchema for DevicesListResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DevicesListResult
impl PartialEq for DevicesListResult
Sourceimpl Serialize for DevicesListResult
impl Serialize for DevicesListResult
impl StructuralPartialEq for DevicesListResult