pub struct ElementActionOutput {
pub element: UiNodeRef,
}Fields
element: UiNodeRefTrait Implementations
Sourceimpl Clone for ElementActionOutput
impl Clone for ElementActionOutput
Sourcefn clone(&self) -> ElementActionOutput
fn clone(&self) -> ElementActionOutput
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ElementActionOutput
impl Debug for ElementActionOutput
Sourceimpl<'de> Deserialize<'de> for ElementActionOutput
impl<'de> Deserialize<'de> for ElementActionOutput
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ElementActionOutput
Sourceimpl JsonSchema for ElementActionOutput
impl JsonSchema for ElementActionOutput
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ElementActionOutput
impl PartialEq for ElementActionOutput
Sourceimpl Serialize for ElementActionOutput
impl Serialize for ElementActionOutput
impl StructuralPartialEq for ElementActionOutput