pub struct EventStreamCursor {
pub stream_epoch: EventStreamEpoch,
pub session_id: SessionId,
pub sequence: EventSequence,
}Expand description
A Session-scoped, daemon-epoch-scoped application acknowledgement.
Fields
stream_epoch: EventStreamEpochsession_id: SessionIdsequence: EventSequenceTrait Implementations
Sourceimpl Clone for EventStreamCursor
impl Clone for EventStreamCursor
Sourcefn clone(&self) -> EventStreamCursor
fn clone(&self) -> EventStreamCursor
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EventStreamCursor
impl Debug for EventStreamCursor
Sourceimpl<'de> Deserialize<'de> for EventStreamCursor
impl<'de> Deserialize<'de> for EventStreamCursor
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EventStreamCursor
Sourceimpl JsonSchema for EventStreamCursor
impl JsonSchema for EventStreamCursor
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EventStreamCursor
impl PartialEq for EventStreamCursor
Sourceimpl Serialize for EventStreamCursor
impl Serialize for EventStreamCursor
impl StructuralPartialEq for EventStreamCursor