pub struct EventsListParams {
pub session_id: Option<SessionId>,
pub after_sequence: Option<EventSequence>,
pub limit: Option<u32>,
}Expand description
Optional parameters accepted by events.list.
Fields
session_id: Option<SessionId>after_sequence: Option<EventSequence>limit: Option<u32>Trait Implementations
Sourceimpl Clone for EventsListParams
impl Clone for EventsListParams
Sourcefn clone(&self) -> EventsListParams
fn clone(&self) -> EventsListParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EventsListParams
impl Debug for EventsListParams
Sourceimpl Default for EventsListParams
impl Default for EventsListParams
Sourcefn default() -> EventsListParams
fn default() -> EventsListParams
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for EventsListParams
impl<'de> Deserialize<'de> for EventsListParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EventsListParams
Sourceimpl JsonSchema for EventsListParams
impl JsonSchema for EventsListParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EventsListParams
impl PartialEq for EventsListParams
Sourceimpl Serialize for EventsListParams
impl Serialize for EventsListParams
impl StructuralPartialEq for EventsListParams