pub struct EventsStreamEventParams {
pub subscription_id: EventSubscriptionId,
pub cursor: EventStreamCursor,
pub event: TestEvent,
}Fields
subscription_id: EventSubscriptionIdcursor: EventStreamCursorevent: TestEventTrait Implementations
Sourceimpl Clone for EventsStreamEventParams
impl Clone for EventsStreamEventParams
Sourcefn clone(&self) -> EventsStreamEventParams
fn clone(&self) -> EventsStreamEventParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EventsStreamEventParams
impl Debug for EventsStreamEventParams
Sourceimpl<'de> Deserialize<'de> for EventsStreamEventParams
impl<'de> Deserialize<'de> for EventsStreamEventParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EventsStreamEventParams
impl JsonSchema for EventsStreamEventParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EventsStreamEventParams
impl PartialEq for EventsStreamEventParams
Sourceimpl Serialize for EventsStreamEventParams
impl Serialize for EventsStreamEventParams
impl StructuralPartialEq for EventsStreamEventParams