pub struct EventsStreamOpenParams {
pub session_id: SessionId,
pub origin_policy: EventStreamOriginPolicy,
}Fields
session_id: SessionIdorigin_policy: EventStreamOriginPolicyTrait Implementations
Sourceimpl Clone for EventsStreamOpenParams
impl Clone for EventsStreamOpenParams
Sourcefn clone(&self) -> EventsStreamOpenParams
fn clone(&self) -> EventsStreamOpenParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EventsStreamOpenParams
impl Debug for EventsStreamOpenParams
Sourceimpl<'de> Deserialize<'de> for EventsStreamOpenParams
impl<'de> Deserialize<'de> for EventsStreamOpenParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EventsStreamOpenParams
Sourceimpl JsonSchema for EventsStreamOpenParams
impl JsonSchema for EventsStreamOpenParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EventsStreamOpenParams
impl PartialEq for EventsStreamOpenParams
Sourceimpl Serialize for EventsStreamOpenParams
impl Serialize for EventsStreamOpenParams
impl StructuralPartialEq for EventsStreamOpenParams