pub struct EventsStreamOpenResult {
pub endpoint: EventStreamEndpoint,
pub stream_epoch: EventStreamEpoch,
pub expires_at_ms: u64,
}Fields
endpoint: EventStreamEndpointstream_epoch: EventStreamEpochexpires_at_ms: u64Trait Implementations
Sourceimpl Clone for EventsStreamOpenResult
impl Clone for EventsStreamOpenResult
Sourcefn clone(&self) -> EventsStreamOpenResult
fn clone(&self) -> EventsStreamOpenResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EventsStreamOpenResult
impl Debug for EventsStreamOpenResult
Sourceimpl<'de> Deserialize<'de> for EventsStreamOpenResult
impl<'de> Deserialize<'de> for EventsStreamOpenResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EventsStreamOpenResult
Sourceimpl JsonSchema for EventsStreamOpenResult
impl JsonSchema for EventsStreamOpenResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EventsStreamOpenResult
impl PartialEq for EventsStreamOpenResult
Sourceimpl Serialize for EventsStreamOpenResult
impl Serialize for EventsStreamOpenResult
impl StructuralPartialEq for EventsStreamOpenResult