pub struct EventsStreamTerminalParams {
pub subscription_id: EventSubscriptionId,
pub session_id: SessionId,
pub last_emitted_cursor: Option<EventStreamCursor>,
pub termination: EventsStreamTermination,
}Fields
subscription_id: EventSubscriptionIdsession_id: SessionIdlast_emitted_cursor: Option<EventStreamCursor>termination: EventsStreamTerminationTrait Implementations
Sourceimpl Clone for EventsStreamTerminalParams
impl Clone for EventsStreamTerminalParams
Sourcefn clone(&self) -> EventsStreamTerminalParams
fn clone(&self) -> EventsStreamTerminalParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EventsStreamTerminalParams
impl Debug for EventsStreamTerminalParams
Sourceimpl<'de> Deserialize<'de> for EventsStreamTerminalParams
impl<'de> Deserialize<'de> for EventsStreamTerminalParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for EventsStreamTerminalParams
impl JsonSchema for EventsStreamTerminalParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for EventsStreamTerminalParams