pub struct EventsSubscribeParams {
pub session_id: SessionId,
pub after_cursor: Option<EventStreamCursor>,
}Fields
session_id: SessionIdafter_cursor: Option<EventStreamCursor>Trait Implementations
Sourceimpl Clone for EventsSubscribeParams
impl Clone for EventsSubscribeParams
Sourcefn clone(&self) -> EventsSubscribeParams
fn clone(&self) -> EventsSubscribeParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EventsSubscribeParams
impl Debug for EventsSubscribeParams
Sourceimpl<'de> Deserialize<'de> for EventsSubscribeParams
impl<'de> Deserialize<'de> for EventsSubscribeParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EventsSubscribeParams
Sourceimpl JsonSchema for EventsSubscribeParams
impl JsonSchema for EventsSubscribeParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EventsSubscribeParams
impl PartialEq for EventsSubscribeParams
Sourceimpl Serialize for EventsSubscribeParams
impl Serialize for EventsSubscribeParams
impl StructuralPartialEq for EventsSubscribeParams