pub struct EventsSubscribeResult {
pub subscription_id: EventSubscriptionId,
pub session_id: SessionId,
pub replay_through: EventStreamCursor,
pub session_state: SessionState,
}Fields
subscription_id: EventSubscriptionIdsession_id: SessionIdreplay_through: EventStreamCursorsession_state: SessionStateTrait Implementations
Sourceimpl Clone for EventsSubscribeResult
impl Clone for EventsSubscribeResult
Sourcefn clone(&self) -> EventsSubscribeResult
fn clone(&self) -> EventsSubscribeResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EventsSubscribeResult
impl Debug for EventsSubscribeResult
Sourceimpl<'de> Deserialize<'de> for EventsSubscribeResult
impl<'de> Deserialize<'de> for EventsSubscribeResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for EventsSubscribeResult
Sourceimpl JsonSchema for EventsSubscribeResult
impl JsonSchema for EventsSubscribeResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for EventsSubscribeResult
impl PartialEq for EventsSubscribeResult
Sourceimpl Serialize for EventsSubscribeResult
impl Serialize for EventsSubscribeResult
impl StructuralPartialEq for EventsSubscribeResult