pub struct FeatureSelection {
pub enabled: BTreeSet<String>,
}Fields
enabled: BTreeSet<String>Trait Implementations
Sourceimpl Clone for FeatureSelection
impl Clone for FeatureSelection
Sourcefn clone(&self) -> FeatureSelection
fn clone(&self) -> FeatureSelection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FeatureSelection
impl Debug for FeatureSelection
Sourceimpl Default for FeatureSelection
impl Default for FeatureSelection
Sourcefn default() -> FeatureSelection
fn default() -> FeatureSelection
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for FeatureSelection
impl<'de> Deserialize<'de> for FeatureSelection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for FeatureSelection
Sourceimpl JsonSchema for FeatureSelection
impl JsonSchema for FeatureSelection
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FeatureSelection
impl PartialEq for FeatureSelection
Sourceimpl Serialize for FeatureSelection
impl Serialize for FeatureSelection
impl StructuralPartialEq for FeatureSelection