pub struct HelloParams {
pub client: PeerInfo,
pub protocol: ProtocolOffer,
pub features: FeatureOffer,
}Fields
client: PeerInfoprotocol: ProtocolOfferfeatures: FeatureOfferTrait Implementations
Sourceimpl Clone for HelloParams
impl Clone for HelloParams
Sourcefn clone(&self) -> HelloParams
fn clone(&self) -> HelloParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HelloParams
impl Debug for HelloParams
Sourceimpl<'de> Deserialize<'de> for HelloParams
impl<'de> Deserialize<'de> for HelloParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for HelloParams
Sourceimpl JsonSchema for HelloParams
impl JsonSchema for HelloParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for HelloParams
impl PartialEq for HelloParams
Sourceimpl Serialize for HelloParams
impl Serialize for HelloParams
impl StructuralPartialEq for HelloParams