pub struct HelloResult {
pub connection_id: Uuid,
pub protocol: ProtocolSelection,
pub server: PeerInfo,
pub transport: TransportInfo,
pub features: FeatureSelection,
}Fields
connection_id: Uuidprotocol: ProtocolSelectionserver: PeerInfotransport: TransportInfofeatures: FeatureSelectionTrait Implementations
Sourceimpl Clone for HelloResult
impl Clone for HelloResult
Sourcefn clone(&self) -> HelloResult
fn clone(&self) -> HelloResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HelloResult
impl Debug for HelloResult
Sourceimpl<'de> Deserialize<'de> for HelloResult
impl<'de> Deserialize<'de> for HelloResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for HelloResult
Sourceimpl JsonSchema for HelloResult
impl JsonSchema for HelloResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for HelloResult
impl PartialEq for HelloResult
Sourceimpl Serialize for HelloResult
impl Serialize for HelloResult
impl StructuralPartialEq for HelloResult