pub struct ManualActionStep {
pub sequence: EventSequence,
pub captured_at_ms: u64,
pub call_id: Uuid,
pub name: String,
pub arguments: ManualActionArguments,
}Fields
sequence: EventSequencecaptured_at_ms: u64call_id: Uuidname: Stringarguments: ManualActionArgumentsTrait Implementations
Sourceimpl Clone for ManualActionStep
impl Clone for ManualActionStep
Sourcefn clone(&self) -> ManualActionStep
fn clone(&self) -> ManualActionStep
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ManualActionStep
impl Debug for ManualActionStep
Sourceimpl<'de> Deserialize<'de> for ManualActionStep
impl<'de> Deserialize<'de> for ManualActionStep
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ManualActionStep
impl JsonSchema for ManualActionStep
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ManualActionStep
impl PartialEq for ManualActionStep
Sourceimpl Serialize for ManualActionStep
impl Serialize for ManualActionStep
impl StructuralPartialEq for ManualActionStep