pub struct ManualRecording {
pub format_version: u16,
pub recording_id: Uuid,
pub source_device_id: DeviceId,
pub action_space_sha256: String,
pub started_at_ms: u64,
pub ended_at_ms: u64,
pub steps: Vec<ManualActionStep>,
}Expand description
A bounded, Driver-neutral record of human-selected Actions.
Protected Action arguments are represented only by an opaque host-owned secret reference. The secret value is never part of this durable DTO.
Fields
format_version: u16recording_id: Uuidsource_device_id: DeviceIdaction_space_sha256: Stringstarted_at_ms: u64ended_at_ms: u64steps: Vec<ManualActionStep>Trait Implementations
Sourceimpl Clone for ManualRecording
impl Clone for ManualRecording
Sourcefn clone(&self) -> ManualRecording
fn clone(&self) -> ManualRecording
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ManualRecording
impl Debug for ManualRecording
Sourceimpl<'de> Deserialize<'de> for ManualRecording
impl<'de> Deserialize<'de> for ManualRecording
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ManualRecording
impl JsonSchema for ManualRecording
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ManualRecording
impl PartialEq for ManualRecording
Sourceimpl Serialize for ManualRecording
impl Serialize for ManualRecording
impl StructuralPartialEq for ManualRecording