pub struct MediaFrame {
pub stream_id: MediaStreamId,
pub frame_index: EventSequence,
pub key_frame: bool,
pub duration_ms: Option<u64>,
pub evidence: AssetRef,
}Fields
stream_id: MediaStreamIdframe_index: EventSequencekey_frame: boolduration_ms: Option<u64>evidence: AssetRefTrait Implementations
Sourceimpl Clone for MediaFrame
impl Clone for MediaFrame
Sourcefn clone(&self) -> MediaFrame
fn clone(&self) -> MediaFrame
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MediaFrame
impl Debug for MediaFrame
Sourceimpl<'de> Deserialize<'de> for MediaFrame
impl<'de> Deserialize<'de> for MediaFrame
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MediaFrame
impl JsonSchema for MediaFrame
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MediaFrame
impl PartialEq for MediaFrame
Sourceimpl Serialize for MediaFrame
impl Serialize for MediaFrame
impl StructuralPartialEq for MediaFrame