pub struct MediaStreamCaptureParams {
pub stream_id: MediaStreamId,
pub frame_index: EventSequence,
pub duration_ms: Option<u64>,
}Expand description
Parameters accepted by media.stream.capture.
Fields
stream_id: MediaStreamIdframe_index: EventSequenceCaller-declared one-based frame index. Retrying the same accepted index is idempotent; advancing it is the caller’s acknowledgement boundary.
duration_ms: Option<u64>Trait Implementations
Sourceimpl Clone for MediaStreamCaptureParams
impl Clone for MediaStreamCaptureParams
Sourcefn clone(&self) -> MediaStreamCaptureParams
fn clone(&self) -> MediaStreamCaptureParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MediaStreamCaptureParams
impl Debug for MediaStreamCaptureParams
Sourceimpl<'de> Deserialize<'de> for MediaStreamCaptureParams
impl<'de> Deserialize<'de> for MediaStreamCaptureParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MediaStreamCaptureParams
Sourceimpl JsonSchema for MediaStreamCaptureParams
impl JsonSchema for MediaStreamCaptureParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MediaStreamCaptureParams
impl PartialEq for MediaStreamCaptureParams
Sourceimpl Serialize for MediaStreamCaptureParams
impl Serialize for MediaStreamCaptureParams
impl StructuralPartialEq for MediaStreamCaptureParams