pub struct MediaStreamEndParams {
pub stream_id: MediaStreamId,
}Expand description
Parameters accepted by media.stream.end.
Fields
stream_id: MediaStreamIdTrait Implementations
Sourceimpl Clone for MediaStreamEndParams
impl Clone for MediaStreamEndParams
Sourcefn clone(&self) -> MediaStreamEndParams
fn clone(&self) -> MediaStreamEndParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MediaStreamEndParams
impl Debug for MediaStreamEndParams
Sourceimpl<'de> Deserialize<'de> for MediaStreamEndParams
impl<'de> Deserialize<'de> for MediaStreamEndParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MediaStreamEndParams
Sourceimpl JsonSchema for MediaStreamEndParams
impl JsonSchema for MediaStreamEndParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MediaStreamEndParams
impl PartialEq for MediaStreamEndParams
Sourceimpl Serialize for MediaStreamEndParams
impl Serialize for MediaStreamEndParams
impl StructuralPartialEq for MediaStreamEndParams