pub struct MediaStreamInfo {
pub id: MediaStreamId,
pub kind: MediaStreamKind,
pub media_type: String,
pub viewport: Option<Viewport>,
}Fields
id: MediaStreamIdkind: MediaStreamKindmedia_type: Stringviewport: Option<Viewport>Trait Implementations
Sourceimpl Clone for MediaStreamInfo
impl Clone for MediaStreamInfo
Sourcefn clone(&self) -> MediaStreamInfo
fn clone(&self) -> MediaStreamInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MediaStreamInfo
impl Debug for MediaStreamInfo
Sourceimpl<'de> Deserialize<'de> for MediaStreamInfo
impl<'de> Deserialize<'de> for MediaStreamInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MediaStreamInfo
impl JsonSchema for MediaStreamInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MediaStreamInfo
impl PartialEq for MediaStreamInfo
Sourceimpl Serialize for MediaStreamInfo
impl Serialize for MediaStreamInfo
impl StructuralPartialEq for MediaStreamInfo