pub struct MediaStreamStartParams {
pub stream_id: MediaStreamId,
pub kind: MediaStreamKind,
}Expand description
Parameters accepted by media.stream.start.
The caller chooses only a lifetime-unique stream identifier and the logical stream kind. The daemon assigns the media type from its selected, leased device producer; viewport metadata may be absent. This control method never accepts frame bytes, Evidence references, or filesystem paths.
Fields
stream_id: MediaStreamIdkind: MediaStreamKindTrait Implementations
Sourceimpl Clone for MediaStreamStartParams
impl Clone for MediaStreamStartParams
Sourcefn clone(&self) -> MediaStreamStartParams
fn clone(&self) -> MediaStreamStartParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MediaStreamStartParams
impl Debug for MediaStreamStartParams
Sourceimpl<'de> Deserialize<'de> for MediaStreamStartParams
impl<'de> Deserialize<'de> for MediaStreamStartParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MediaStreamStartParams
Sourceimpl JsonSchema for MediaStreamStartParams
impl JsonSchema for MediaStreamStartParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MediaStreamStartParams
impl PartialEq for MediaStreamStartParams
Sourceimpl Serialize for MediaStreamStartParams
impl Serialize for MediaStreamStartParams
impl StructuralPartialEq for MediaStreamStartParams