pub struct Observation {
pub id: Uuid,
pub device_id: DeviceId,
pub captured_at_ms: u64,
pub viewport: Viewport,
pub screenshot: Option<AssetRef>,
pub screenshot_omission: Option<ScreenshotOmissionReason>,
pub ui_snapshot: Option<UiSnapshotRef>,
pub ui_snapshot_omission: Option<UiSnapshotOmissionReason>,
pub metadata: Map<String, Value>,
}Fields
id: Uuiddevice_id: DeviceIdcaptured_at_ms: u64viewport: Viewportscreenshot: Option<AssetRef>screenshot_omission: Option<ScreenshotOmissionReason>ui_snapshot: Option<UiSnapshotRef>ui_snapshot_omission: Option<UiSnapshotOmissionReason>metadata: Map<String, Value>Implementations
Sourceimpl Observation
impl Observation
Sourcepub fn asset_refs(&self) -> impl Iterator<Item = &AssetRef>
pub fn asset_refs(&self) -> impl Iterator<Item = &AssetRef>
Returns every typed Evidence reference owned by this Observation.
Sourcepub const fn ui_snapshot_state_is_valid(&self) -> bool
pub const fn ui_snapshot_state_is_valid(&self) -> bool
A snapshot and its omission reason are mutually exclusive. Both absent preserves the pre-1.5 Observation shape and represents no claim.