pub struct ProtocolSelection {
pub selected: ProtocolVersion,
}Fields
selected: ProtocolVersionTrait Implementations
Sourceimpl Clone for ProtocolSelection
impl Clone for ProtocolSelection
Sourcefn clone(&self) -> ProtocolSelection
fn clone(&self) -> ProtocolSelection
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProtocolSelection
impl Debug for ProtocolSelection
Sourceimpl<'de> Deserialize<'de> for ProtocolSelection
impl<'de> Deserialize<'de> for ProtocolSelection
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ProtocolSelection
Sourceimpl JsonSchema for ProtocolSelection
impl JsonSchema for ProtocolSelection
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProtocolSelection
impl PartialEq for ProtocolSelection
Sourceimpl Serialize for ProtocolSelection
impl Serialize for ProtocolSelection
impl StructuralPartialEq for ProtocolSelection