pub struct RequestCancelParams {
pub request_id: RpcId,
}Fields
request_id: RpcIdTrait Implementations
Sourceimpl Clone for RequestCancelParams
impl Clone for RequestCancelParams
Sourcefn clone(&self) -> RequestCancelParams
fn clone(&self) -> RequestCancelParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RequestCancelParams
impl Debug for RequestCancelParams
Sourceimpl<'de> Deserialize<'de> for RequestCancelParams
impl<'de> Deserialize<'de> for RequestCancelParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for RequestCancelParams
Sourceimpl JsonSchema for RequestCancelParams
impl JsonSchema for RequestCancelParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for RequestCancelParams
impl PartialEq for RequestCancelParams
Sourceimpl Serialize for RequestCancelParams
impl Serialize for RequestCancelParams
impl StructuralPartialEq for RequestCancelParams