pub struct SessionCurrentResult {
pub session_id: SessionId,
}Expand description
Result returned by session.current.
Fields
session_id: SessionIdTrait Implementations
Sourceimpl Clone for SessionCurrentResult
impl Clone for SessionCurrentResult
Sourcefn clone(&self) -> SessionCurrentResult
fn clone(&self) -> SessionCurrentResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionCurrentResult
impl Debug for SessionCurrentResult
Sourceimpl<'de> Deserialize<'de> for SessionCurrentResult
impl<'de> Deserialize<'de> for SessionCurrentResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SessionCurrentResult
Sourceimpl JsonSchema for SessionCurrentResult
impl JsonSchema for SessionCurrentResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SessionCurrentResult
impl PartialEq for SessionCurrentResult
Sourceimpl Serialize for SessionCurrentResult
impl Serialize for SessionCurrentResult
impl StructuralPartialEq for SessionCurrentResult