pub struct SessionEndParams {
pub outcome: Option<SessionOutcome>,
pub reason: Option<String>,
}Expand description
Optional parameters accepted by session.end.
Fields
outcome: Option<SessionOutcome>reason: Option<String>Trait Implementations
Sourceimpl Clone for SessionEndParams
impl Clone for SessionEndParams
Sourcefn clone(&self) -> SessionEndParams
fn clone(&self) -> SessionEndParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionEndParams
impl Debug for SessionEndParams
Sourceimpl Default for SessionEndParams
impl Default for SessionEndParams
Sourcefn default() -> SessionEndParams
fn default() -> SessionEndParams
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SessionEndParams
impl<'de> Deserialize<'de> for SessionEndParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SessionEndParams
Sourceimpl JsonSchema for SessionEndParams
impl JsonSchema for SessionEndParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SessionEndParams
impl PartialEq for SessionEndParams
Sourceimpl Serialize for SessionEndParams
impl Serialize for SessionEndParams
impl StructuralPartialEq for SessionEndParams