pub struct SessionExport {
pub session: SessionInfo,
pub events: Vec<TestEvent>,
}Fields
session: SessionInfoevents: Vec<TestEvent>Trait Implementations
Sourceimpl Clone for SessionExport
impl Clone for SessionExport
Sourcefn clone(&self) -> SessionExport
fn clone(&self) -> SessionExport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionExport
impl Debug for SessionExport
Sourceimpl<'de> Deserialize<'de> for SessionExport
impl<'de> Deserialize<'de> for SessionExport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<SessionExport> for SessionExportResult
impl From<SessionExport> for SessionExportResult
Sourcefn from(export: SessionExport) -> Self
fn from(export: SessionExport) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for SessionExport
impl JsonSchema for SessionExport
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SessionExport
impl PartialEq for SessionExport
Sourceimpl Serialize for SessionExport
impl Serialize for SessionExport
impl StructuralPartialEq for SessionExport