pub struct SessionExportResult {
pub session: SessionInfo,
pub events: Vec<TestEvent>,
pub next_after_sequence: Option<EventSequence>,
}Expand description
Result returned by session.export.
nextAfterSequence is absent for a legacy complete export and for the
final page. A paged response includes it only when another page remains.
Fields
session: SessionInfoevents: Vec<TestEvent>next_after_sequence: Option<EventSequence>Trait Implementations
Sourceimpl Clone for SessionExportResult
impl Clone for SessionExportResult
Sourcefn clone(&self) -> SessionExportResult
fn clone(&self) -> SessionExportResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionExportResult
impl Debug for SessionExportResult
Sourceimpl<'de> Deserialize<'de> for SessionExportResult
impl<'de> Deserialize<'de> for SessionExportResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<SessionExport> for SessionExportResult
impl From<SessionExport> for SessionExportResult
Sourcefn from(export: SessionExport) -> Self
fn from(export: SessionExport) -> Self
Converts to this type from the input type.
Sourceimpl JsonSchema for SessionExportResult
impl JsonSchema for SessionExportResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SessionExportResult
impl PartialEq for SessionExportResult
Sourceimpl Serialize for SessionExportResult
impl Serialize for SessionExportResult
impl StructuralPartialEq for SessionExportResult