pub struct SessionInfo {
pub id: SessionId,
pub state: SessionState,
pub started_at_ms: u64,
pub ended_at_ms: Option<u64>,
pub event_count: EventSequence,
pub last_sequence: EventSequence,
}Fields
id: SessionIdstate: SessionStatestarted_at_ms: u64ended_at_ms: Option<u64>event_count: EventSequencelast_sequence: EventSequenceTrait Implementations
Sourceimpl Clone for SessionInfo
impl Clone for SessionInfo
Sourcefn clone(&self) -> SessionInfo
fn clone(&self) -> SessionInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionInfo
impl Debug for SessionInfo
Sourceimpl<'de> Deserialize<'de> for SessionInfo
impl<'de> Deserialize<'de> for SessionInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SessionInfo
Sourceimpl JsonSchema for SessionInfo
impl JsonSchema for SessionInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SessionInfo
impl PartialEq for SessionInfo
Sourceimpl Serialize for SessionInfo
impl Serialize for SessionInfo
impl StructuralPartialEq for SessionInfo