pub struct SessionTargetParams {
pub session_id: Option<SessionId>,
}Expand description
Optional session selector accepted by events.clear.
Fields
session_id: Option<SessionId>Trait Implementations
Sourceimpl Clone for SessionTargetParams
impl Clone for SessionTargetParams
Sourcefn clone(&self) -> SessionTargetParams
fn clone(&self) -> SessionTargetParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SessionTargetParams
impl Debug for SessionTargetParams
Sourceimpl Default for SessionTargetParams
impl Default for SessionTargetParams
Sourcefn default() -> SessionTargetParams
fn default() -> SessionTargetParams
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for SessionTargetParams
impl<'de> Deserialize<'de> for SessionTargetParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SessionTargetParams
Sourceimpl JsonSchema for SessionTargetParams
impl JsonSchema for SessionTargetParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SessionTargetParams
impl PartialEq for SessionTargetParams
Sourceimpl Serialize for SessionTargetParams
impl Serialize for SessionTargetParams
impl StructuralPartialEq for SessionTargetParams