pub struct SystemDescribeResult {
pub connection: HelloResult,
pub client: PeerInfo,
pub device_id: Option<DeviceId>,
pub active_session_id: Option<SessionId>,
}Expand description
Result returned by system.describe.
Fields
connection: HelloResultclient: PeerInfodevice_id: Option<DeviceId>active_session_id: Option<SessionId>Trait Implementations
Sourceimpl Clone for SystemDescribeResult
impl Clone for SystemDescribeResult
Sourcefn clone(&self) -> SystemDescribeResult
fn clone(&self) -> SystemDescribeResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SystemDescribeResult
impl Debug for SystemDescribeResult
Sourceimpl<'de> Deserialize<'de> for SystemDescribeResult
impl<'de> Deserialize<'de> for SystemDescribeResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SystemDescribeResult
Sourceimpl JsonSchema for SystemDescribeResult
impl JsonSchema for SystemDescribeResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SystemDescribeResult
impl PartialEq for SystemDescribeResult
Sourceimpl Serialize for SystemDescribeResult
impl Serialize for SystemDescribeResult
impl StructuralPartialEq for SystemDescribeResult