pub struct TransportInfo {
pub kind: String,
pub framing: String,
}Fields
kind: Stringframing: StringTrait Implementations
Sourceimpl Clone for TransportInfo
impl Clone for TransportInfo
Sourcefn clone(&self) -> TransportInfo
fn clone(&self) -> TransportInfo
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TransportInfo
impl Debug for TransportInfo
Sourceimpl<'de> Deserialize<'de> for TransportInfo
impl<'de> Deserialize<'de> for TransportInfo
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TransportInfo
Sourceimpl JsonSchema for TransportInfo
impl JsonSchema for TransportInfo
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TransportInfo
impl PartialEq for TransportInfo
Sourceimpl Serialize for TransportInfo
impl Serialize for TransportInfo
impl StructuralPartialEq for TransportInfo