pub struct UiSnapshotGetParams {
pub observation_id: Uuid,
}Expand description
Parameters accepted by ui.snapshot.get.
The active Session owns the Observation lookup; callers cannot name a different Session or provide an arbitrary Evidence reference.
Fields
observation_id: UuidTrait Implementations
Sourceimpl Clone for UiSnapshotGetParams
impl Clone for UiSnapshotGetParams
Sourcefn clone(&self) -> UiSnapshotGetParams
fn clone(&self) -> UiSnapshotGetParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UiSnapshotGetParams
impl Debug for UiSnapshotGetParams
Sourceimpl<'de> Deserialize<'de> for UiSnapshotGetParams
impl<'de> Deserialize<'de> for UiSnapshotGetParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for UiSnapshotGetParams
Sourceimpl JsonSchema for UiSnapshotGetParams
impl JsonSchema for UiSnapshotGetParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for UiSnapshotGetParams
impl PartialEq for UiSnapshotGetParams
Sourceimpl Serialize for UiSnapshotGetParams
impl Serialize for UiSnapshotGetParams
impl StructuralPartialEq for UiSnapshotGetParams