pub struct VerdictRecordParams {
pub verdict: Verdict,
}Expand description
Parameters accepted by verdict.record.
DeviceRail persists this caller-supplied Verdict; it does not infer or upgrade the verdict status.
Fields
verdict: VerdictTrait Implementations
Sourceimpl Clone for VerdictRecordParams
impl Clone for VerdictRecordParams
Sourcefn clone(&self) -> VerdictRecordParams
fn clone(&self) -> VerdictRecordParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerdictRecordParams
impl Debug for VerdictRecordParams
Sourceimpl<'de> Deserialize<'de> for VerdictRecordParams
impl<'de> Deserialize<'de> for VerdictRecordParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VerdictRecordParams
impl JsonSchema for VerdictRecordParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VerdictRecordParams
impl PartialEq for VerdictRecordParams
Sourceimpl Serialize for VerdictRecordParams
impl Serialize for VerdictRecordParams
impl StructuralPartialEq for VerdictRecordParams