pub struct VerdictRecordResult {
pub event: TestEvent,
}Expand description
Result returned by verdict.record after the durable event append.
Fields
event: TestEventTrait Implementations
Sourceimpl Clone for VerdictRecordResult
impl Clone for VerdictRecordResult
Sourcefn clone(&self) -> VerdictRecordResult
fn clone(&self) -> VerdictRecordResult
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VerdictRecordResult
impl Debug for VerdictRecordResult
Sourceimpl<'de> Deserialize<'de> for VerdictRecordResult
impl<'de> Deserialize<'de> for VerdictRecordResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for VerdictRecordResult
impl JsonSchema for VerdictRecordResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for VerdictRecordResult
impl PartialEq for VerdictRecordResult
Sourceimpl Serialize for VerdictRecordResult
impl Serialize for VerdictRecordResult
impl StructuralPartialEq for VerdictRecordResult